% Landsat Load - Luke Carberry, 03/16/2022
% Function to load Landsat 8 netcdf files, flag the bad pixels, and save .mat files from them
% requires chlflag.m function
% .mat files are used by landsat_plot.m to make figures

clear all
addpath('/scratch/coast/surface_spectra/tools'); %directory for functions

cd /scratch/coast/surface_spectra/landsat/SBC/1collection/ncfiles %directory for ncfiles

files = dir('*.L2_LAC_OC');

for i = 1:length(files)
cd /scratch/coast/surface_spectra/landsat/SBC/1collection/ncfiles %directory where ncfiles are stored
  
    info = ncinfo(files(i).name); %netcdf info if you need it

    %chlorophyll processed using the standard Landsat NASA product. Uses
    %OCX algorithm at high chlorophyll (O'Reilly et al., 1998; O'Reilly and Werdell, 2019) 
    %and Chuanmin Hu's line height algorithm at low chlorophyll (Hu et al., 2012)
    chl = ncread(files(i).name, ['/geophysical_data/','chl_oci']); 
    
    %Particulate backscattering at 443 processed using the Generalized
    %Inherent Optical Property (GIOP) model (Werdell et al., 2013)
    bbp_443_giop = ncread(files(i).name, ['/geophysical_data/','bbp_443_giop']);
    
    %Particulate backscattering at 443 processed using the
    %Garver-Siegel-Maritorena algorithm
    bbp_443_gsm = ncread(files(i).name, ['/geophysical_data/','bbp_443_gsm']);
    
    lat = ncread(files(i).name, ['/navigation_data/', 'latitude']); %latitude in navigation data 
    lon = ncread(files(i).name, ['/navigation_data/', 'longitude']); %longitude in navigation data 
    flags = ncread(files(i).name, ['/geophysical_data/','l2_flags']); %chlorophyll algorithm flags

    
    % flag chlorophyll matrix to remove bad pixels
    % needs chlflag.m function
    % read function to learn which flags are in use
    % THIS IS AN IMPORTANT STEP
    chl = chlflag(chl,flags);
    
    %save mat file to a separate directory
    str = files(i).name;
    str = erase(str,str(1:17));
    str = str(1:8);
    str = strcat('LS_',str,'.mat');
    cd /scratch/coast/surface_spectra/landsat/SBC/1collection/mat/ %navigate to save directory
    save(str,'info','chl','bbp_443_giop','bbp_443_gsm','flags','lat','lon')

    i %print index to watch progress

end
    
 
