% Landsat Plot - Luke Carberry, 03/16/2022
% script to plot images of Landsat chlorophyll (and particulate
% backscattering) 

% requires fill_holes.m, subregion.m, inpaint_nans.m, cmocean.m functions

% steps: 
% 1) load .mat file 
% 2) interpolate over small holes 
% 3) define subregions for smaller analysis (and quicker plotting)
% 4) save figures

clear all
%directory for functions
addpath('/scratch/coast/surface_spectra/tools'); 

%directory where .mat files are stored
cd /scratch/coast/surface_spectra/landsat/SBC/1collection/ncfiles 

files = dir('*.mat');

% loop is not necessary! comment out and just run the script by hand if you
% like
for i = 1:length(files)
    % .mat directory
    cd /scratch/coast/surface_spectra/landsat/SBC/1collection/mat
    
    % load file
    load(files(i).name,'lat','lon','chl')
  
    % interpolate over the few lone NaNs in image to clear up the image for
    % analysis. Needs fill_holes.m and inpaint_nans.m functions.
    % See those functions for info about interpolation methods.
    % hole_size = the minimum NaN hole size that is NOT interpolated over
    method = 5; 
    hole_size = 14;
    chl_fill = fill_holes(chl,hole_size,method);

    % define a subregion if you wish
    rsublat(1,:) = [33.55 35.2]; %Whole SBC image
    rsublon(1,:) = [-121.1 -118.9];
    rsublat(2,:) = [34.3,34.42]; %Goleta Bay
    rsublon(2,:) = [-119.87,-119.7];
    rsublat(3,:) = [34.15 34.4]; %wide SBC
    rsublon(3,:) = [-120.6 -120];
    rsublat(4,:) = [34.28 34.38]; %small SBC
    rsublon(4,:) = [-120.14 -120];
    rsublat(5,:) = [34.32 34.42]; %coal oil point
    rsublon(5,:) = [-119.9 -119.75];

    % save a matrix for a smaller region
    % needs subregion.m function 
    r = 3;
    clear lats lons chls
    [lats,lons,chls] = subregion(lat,lon,chl_fill,rsublat(r,:),rsublon(r,:));
    
    % plot a figure 
    figure(1),clf
    subplot(1,2,1)
    h = pcolor(lon,lat,chl_fill);
    set(h,'linestyle','none')
    map=cmocean('algae');colormap(gca,map);
    % xlim([-121.1 -118.9]),ylim([33.55 35.2]);
    set(gca, 'FontSize',14);caxis([0 4]);
    c=colorbar;title('Santa Barbara Channel')
    c.Label.String = 'Chl (mg m^{-3})';c.FontSize=14; %labels the colorbar
    xlabel('Longitude','FontSize',14); %labels x axis
    ylabel('Latitude','FontSize',14); %labels y axiscolorbar;
    daspect([1/cos(mean(lat,'all')*pi/180) 1 1])
    
    subplot(1,2,2)
    h = pcolor(lons,lats,chls);
    set(h,'linestyle','none')
    map=cmocean('algae');colormap(gca,map);
    % xlim([-121.1 -118.9]),ylim([33.55 35.2]);
    set(gca, 'FontSize',14);caxis([0 4]);
    c=colorbar;title('Subregion')
    c.Label.String = 'Chl (mg m^{-3})';c.FontSize=14; %labels the colorbar
    xlabel('Longitude','FontSize',14); %labels x axis
    ylabel('Latitude','FontSize',14); %labels y axiscolorbar;
    daspect([1/cos(mean(lat,'all')*pi/180) 1 1])

    cd /scratch/coast/surface_spectra/landsat/SBC/1collection/zchlfigs4 %directory to save figures
    str = files(i).name;
    str = str(4:11);
    str = strcat(str,'_SBC.jpg');
    print(gcf, '-djpeg100',str, '-r600');

    
end
    
    